============================
Strava Model Module
============================
.. currentmodule:: stravalib.strava_model

The `strava-model` module contains the officially documented Strava API
entities. This module is generated by a bot and should not be edited manually.

.. automodule:: stravalib.strava_model
   :members:
   :undoc-members:
